<?php
/**
 * Plugin Name: Announce
 * Description: 一个显示浮动弹窗的插件
 * Version: 1.0
 * Author: Nibbles
 */

if (!defined('ABSPATH')) {
    exit; // 防止直接访问
}

// 加载插件所需的脚本和样式
function announce_enqueue_scripts() {
    wp_enqueue_style('announce-style', plugin_dir_url(__FILE__) . 'css/announce.css');
    wp_enqueue_script('announce-script', plugin_dir_url(__FILE__) . 'js/announce.js', array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'announce_enqueue_scripts');

// 在页面中插入弹窗的HTML结构
function announce_display_popup() {
    ?>
    <div id="announce-popup" class="announce-popup">
        <div class="announce-content">
            <h2 id="announce-title"><?php echo esc_html(get_option('announce_title', '提示')); ?></h2>
            <p id="announce-message"><?php echo esc_html(get_option('announce_message', '这是一个重要的公告！')); ?></p>
            <button id="announce-close"><?php _e('已知晓', 'announce'); ?></button>
        </div>
    </div>
    <div id="announce-overlay" class="announce-overlay"></div>
    <?php
}
add_action('wp_footer', 'announce_display_popup');

// 添加插件设置页面
function announce_settings_page() {
    add_options_page(
        'Announce Settings',
        'Announce',
        'manage_options',
        'announce',
        'announce_settings_page_html'
    );
}
add_action('admin_menu', 'announce_settings_page');

function announce_settings_page_html() {
    ?>
    <div class="wrap">
        <h1><?php _e('Announce 设置', 'announce'); ?></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('announce_settings');
            do_settings_sections('announce');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// 注册设置选项
function announce_register_settings() {
    register_setting('announce_settings', 'announce_title');
    register_setting('announce_settings', 'announce_message');

    add_settings_section(
        'announce_section',
        __('弹窗设置', 'announce'),
        null,
        'announce'
    );

    add_settings_field(
        'announce_title',
        __('弹窗标题', 'announce'),
        'announce_title_callback',
        'announce',
        'announce_section'
    );

    add_settings_field(
        'announce_message',
        __('弹窗内容', 'announce'),
        'announce_message_callback',
        'announce',
        'announce_section'
    );
}
add_action('admin_init', 'announce_register_settings');

function announce_title_callback() {
    $announce_title = get_option('announce_title', '');
    echo '<input type="text" name="announce_title" value="' . esc_attr($announce_title) . '" />';
}

function announce_message_callback() {
    $announce_message = get_option('announce_message', '');
    echo '<textarea name="announce_message" rows="5" cols="50">' . esc_textarea($announce_message) . '</textarea>';
}
?>
